<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * This file merges all the install.xml files into one big file.
 *
 * @package     local_aatplugin
 * @copyright  2023 Joseph Larochelle
 * @license    https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
require_once('../../config.php');
require_login();
/**
 * Combines all 'install.xml' files from a given directory and its subdirectories into one large XML file.
 *
 * @param string $directory The base directory to start searching for 'install.xml' files.
 */
function combinexmlfiles($directory) {
    global $CFG;
    $dom = new DOMDocument('1.0', 'UTF-8');
    $root = $dom->createElement('XMLDB');
    $dom->appendChild($root);

    $tableselement = $dom->createElement('TABLES');
    $root->appendChild($tableselement);

    // Initialize a RecursiveIteratorIterator to iterate through directories and files.
    $iterator = new RecursiveIteratorIterator(
            new RecursiveDirectoryIterator($directory),
            RecursiveIteratorIterator::SELF_FIRST
    );

    // Iterate over each item in the directory and its subdirectories.
    foreach ($iterator as $file) {
        if ($file->isFile() && $file->getFilename() == 'install.xml') {
            // Load the XML content of the 'install.xml' file.
            $xml = simplexml_load_file($file->getPathname());
            // Iterate over each '<TABLE>' element within the file.
            foreach ($xml->TABLES->TABLE as $table) {
                $domtable = dom_import_simplexml($table);
                $import = $dom->importNode($domtable, true);
                $tableselement->appendChild($import);
            }
        }
    }
    // Save the combined XML document to a file in Moodle's data root under 'AATplugin/combined_XML_files.xml'.
    $dom->formatOutput = true;
    $dom->save($CFG->dataroot. '/AATplugin/combined_XML_files.xml');
}
