<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * This file contains the library functions for the AAT plugin.
 * @package     local_aatplugin
 * @copyright   2023 Joseph Larochelle <larochellejo@hotmail.com>
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
/**
 * Checks if the current user is an editing teacher.
 *
 * @return bool True if the user is an editing teacher, false otherwise.
 */
function is_editing_teacher() {
    global $DB, $USER;
    $roleid = $DB->get_field('role', 'id', ['shortname' => 'editingteacher']);
    return $DB->record_exists('role_assignments', ['userid' => $USER->id, 'roleid' => $roleid]);
}

/**
 * Insert a link to index.php on the site front page navigation menu if the user is an editing teacher.
 *
 * @param navigation_node $frontpage Node representing the front page in the navigation tree.
 */
function local_aatplugin_extend_navigation_frontpage(navigation_node $frontpage) {
    require_login();
    if (is_editing_teacher()) {
        $frontpage->add(
                get_string('pluginname', 'local_aatplugin'),
                new moodle_url('/local/AATplugin/index.php'),
                navigation_node::TYPE_CUSTOM
        );
    }
}

/**
 * Insert a link to index.php on the course page navigation menu if the user is an editing teacher.
 *
 * @param navigation_node $course Node representing a course in the navigation tree.
 */
function local_aatplugin_extend_navigation_course(navigation_node $course) {
    require_login();
    if (is_editing_teacher()) {
        $course->add(
                get_string('pluginname', 'local_aatplugin'),
                new moodle_url('/local/AATplugin/index.php'),
                navigation_node::TYPE_CUSTOM
        );
    }
}
